@@ -263,13 +263,15 @@ class DefaultDelegate:
         pass
 
     def handleNotification(self, cHandle, data):
-        DBG("Notification:", cHandle, "sent data", binascii.b2a_hex(data))
+        hex_data = binascii.b2a_hex(data)
+        DBG(f"Notification: {cHandle} sent data {hex_data}")
 
     def handleDiscovery(self, scanEntry, isNewDev, isNewData):
-        DBG("Discovered device", scanEntry.addr)
+        dev_str = str(scanEntry.addr)
+        DBG(f"Discovered device {dev_str}")
 
 
-class BluepyHelper:
+class Bluepy3Helper:
     def __init__(self):
         self._helper = None
         self._lineq = None
@@ -283,7 +285,7 @@ class BluepyHelper:
 
     def _startHelper(self, iface=None):
         if self._helper is None:
-            DBG("Running ", helperExe)
+            DBG(f"Running {helperExe}")
             self._aiti = 0
             self._lineq = Queue()
             self._mtu = 0
@@ -313,7 +315,7 @@ class BluepyHelper:
 
     def _stopHelper(self):
         if self._helper is not None:
-            DBG("Stopping ", helperExe)
+            DBG(f"Stopping {helperExe}")
             self._helper.stdin.write("quit\n")
             self._helper.stdin.flush()
             self._helper.wait()
@@ -326,7 +328,7 @@ class BluepyHelper:
     def _writeCmd(self, cmd):
         if self._helper is None:
             raise BTLEInternalError("Helper not started (did you call connect()?)")
-        DBG("Sent: ", cmd)
+        DBG(f"Sent:   {cmd}")
         self._helper.stdin.write(cmd)
         self._helper.stdin.flush()
 
@@ -369,12 +371,12 @@ class BluepyHelper:
             except Empty:
                 DBG("Select timeout")
                 return None
-
-            DBG("Got:", repr(rv))
+            dehex_rv = repr(rv).replace("\\x1e", "; ").replace("\\n", "").replace("'","").strip("\"")
+            DBG(f"Got:    {dehex_rv}")
             if rv.startswith("#") or rv == "\n" or len(rv) == 0:
                 continue
 
-            resp = BluepyHelper.parseResp(rv)
+            resp = Bluepy3Helper.parseResp(rv)
             if "rsp" not in resp:
                 raise BTLEInternalError("No response type indicator", resp)
 
@@ -392,7 +394,7 @@ class BluepyHelper:
                 new_mtu = int(resp["mtu"][0])
                 if self._mtu != new_mtu:
                     self._mtu = new_mtu
-                    DBG("Updated MTU: " + str(self._mtu))
+                    DBG(f"Updated MTU: {str(self._mtu)}")
 
             if respType in wantType:
                 return resp
@@ -419,9 +421,9 @@ class BluepyHelper:
         return self._waitResp(["stat"])
 
 
-class Peripheral(BluepyHelper):
+class Peripheral(Bluepy3Helper):
     def __init__(self, deviceAddr=None, addrType=ADDR_TYPE_PUBLIC, iface=None, timeout=None):
-        BluepyHelper.__init__(self)
+        Bluepy3Helper.__init__(self)
         self._serviceMap = None  # Indexed by UUID
         (self.deviceAddr, self.addrType, self.iface) = (None, None, None)
 
@@ -580,7 +582,7 @@ class Peripheral(BluepyHelper):
         ]
 
     def getDescriptors(self, startHnd=1, endHnd=0xFFFF):
-        self._writeCmd("desc {startHnd}:X} {endHnd:X}\n")
+        self._writeCmd(f"desc {startHnd:X} {endHnd:X}\n")
         # Historical note:
         # Certain Bluetooth LE devices are not capable of sending back all
         # descriptors in one packet due to the limited size of MTU. So the
@@ -849,9 +851,9 @@ class ScanEntry:
         return [(sdid, self.getDescription(sdid), self.getValueText(sdid)) for sdid in self.scanData.keys()]
 
 
-class Scanner(BluepyHelper):
+class Scanner(Bluepy3Helper):
     def __init__(self, iface=0):
-        BluepyHelper.__init__(self)
+        Bluepy3Helper.__init__(self)
         self.scanned = {}
         self.iface = iface
         self.passive = False
